package net.sf.xolite.transform;


import javax.xml.transform.sax.SAXResult;

import net.sf.xolite.XMLObjectFactory;
import net.sf.xolite.XMLParseException;
import net.sf.xolite.XMLSerializable;
import net.sf.xolite.sax.SaxXMLEventParser;
import net.sf.xolite.utils.RootHolder;

import org.xml.sax.XMLReader;


/**
 * Implementation of a XML transformation result that will internally consume the event sent to it to build a XMLSerializable
 * object. This object uses internally a SaxXMLEventParser to interpret the events coming out the XSL transformation.
 * 
 * @author BEROL
 */
public class XMLEventParserResult extends SAXResult {


    private SaxXMLEventParser parser;
    private XMLSerializable root;
    private boolean useRootHolder;


    public XMLEventParserResult() {
        this(new RootHolder());
        useRootHolder = true;
    }


    public XMLEventParserResult(XMLSerializable rootObject) {
        if (rootObject == null) throw new IllegalArgumentException("Root XMLSerializable object cannot be null");
        root = rootObject;
        parser = new SaxXMLEventParser((XMLReader) null);
        setHandler(parser.initForExternalRead(root));
    }


    public void setXmlObjectFactory(XMLObjectFactory factory) {
        parser.setFactory(factory);
    }


    public XMLObjectFactory getXmlObjectFactory() throws XMLParseException {
        return parser.getFactory();
    }


    public XMLSerializable getParsedObject() {
        if (useRootHolder) return ((RootHolder) root).getRoot();
        return root;
    }


}
